#ifndef HISTORYWINDOW_H
#define HISTORYWINDOW_H


#include <QMainWindow>
#include <QtGui>
#include "xml.h"
#include "dayhistory.h"
#include "qmaemo5rotator.h"

//class ListWindow;
//class FoodWindow;

class HistoryWindow : public QMainWindow
{
    Q_OBJECT

public:
    explicit HistoryWindow(QWidget *parent = 0);
    void load();
    QMaemo5Rotator *hwRot;

private:
    DayHistory *dh;
    XML *xml;


    QListView *lstDates;
    QStandardItemModel *model;

    QList <QString> dates;

private slots:
    void showExercises(QModelIndex index);

};

#endif
